Room

Struct Room 

pub struct Room {
Show 43 fields matrix_room: OnceCell<Room>, session: WeakRef<Session>, room_id_string: PhantomData<String>, aliases: RoomAliases, name: RefCell<Option<String>>, has_avatar: Cell<bool>, topic: RefCell<Option<String>>, topic_linkified: RefCell<Option<String>>, category: Cell<RoomCategory>, is_direct: Cell<bool>, is_tombstoned: Cell<bool>, pub(super) predecessor_id: OnceCell<OwnedRoomId>, predecessor_id_string: PhantomData<Option<String>>, pub(super) successor_id: OnceCell<OwnedRoomId>, successor_id_string: PhantomData<Option<String>>, successor: WeakRef<Room>, pub(super) members: WeakRef<MemberList>, members_drop_guard: OnceCell<EventHandlerDropGuard>, joined_members_count: Cell<u64>, own_member: OnceCell<Member>, is_invite: Cell<bool>, inviter: RefCell<Option<Member>>, direct_member: RefCell<Option<Member>>, live_timeline: OnceCell<Timeline>, latest_activity: Cell<u64>, is_marked_unread: Cell<bool>, is_read: Cell<bool>, notification_count: Cell<u64>, has_notifications: Cell<bool>, highlight: Cell<HighlightFlags>, is_encrypted: Cell<bool>, join_rule: JoinRule, guests_allowed: Cell<bool>, history_visibility: Cell<HistoryVisibilityValue>, version: PhantomData<String>, federated: PhantomData<bool>, typing_list: TypingList, typing_drop_guard: OnceCell<EventHandlerDropGuard>, notifications_setting: Cell<NotificationsRoomSetting>, permissions: Permissions, verification: BoundObjectWeakRef<IdentityVerification>, is_room_info_initialized: Cell<bool>, attempted_auto_join: Cell<bool>,
}

Fields

matrix_room: OnceCell<Room>

The room API of the SDK.

session: WeakRef<Session>

The current session.

room_id_string: PhantomData<String>

The ID of this room, as a string.

aliases: RoomAliases

The aliases of this room.

name: RefCell<Option<String>>

The name that is set for this room.

This can be empty, the display name should be used instead in the interface.

has_avatar: Cell<bool>

Whether this room has an avatar explicitly set.

This is false if there is no avatar or if the avatar is the one from the other member.

topic: RefCell<Option<String>>

The topic of this room.

topic_linkified: RefCell<Option<String>>

The linkified topic of this room.

This is the string that should be used in the interface when markup is allowed.

category: Cell<RoomCategory>

The category of this room.

is_direct: Cell<bool>

Whether this room is a direct chat.

is_tombstoned: Cell<bool>

Whether this room has been upgraded.

predecessor_id: OnceCell<OwnedRoomId>

The ID of the room that was upgraded and that this one replaces.

predecessor_id_string: PhantomData<Option<String>>

The ID of the room that was upgraded and that this one replaces, as a string.

successor_id: OnceCell<OwnedRoomId>

The ID of the successor of this Room, if this room was upgraded.

successor_id_string: PhantomData<Option<String>>

The ID of the successor of this Room, if this room was upgraded, as a string.

successor: WeakRef<Room>

The successor of this Room, if this room was upgraded and the successor was joined.

members: WeakRef<MemberList>

The members of this room.

members_drop_guard: OnceCell<EventHandlerDropGuard>joined_members_count: Cell<u64>

The number of joined members in the room, according to the homeserver.

own_member: OnceCell<Member>

The member corresponding to our own user.

is_invite: Cell<bool>

Whether this room is a current invite or an invite that was declined or retracted.

inviter: RefCell<Option<Member>>

The user who sent the invite to this room.

This is only set when this room is an invitation.

direct_member: RefCell<Option<Member>>

The other member of the room, if this room is a direct chat and there is only one other member.

live_timeline: OnceCell<Timeline>

The live timeline of this room.

latest_activity: Cell<u64>

The timestamp of the room’s latest activity.

This is the timestamp of the latest event that counts as possibly unread.

If it is not known, it will return 0.

is_marked_unread: Cell<bool>

Whether this room is marked as unread.

is_read: Cell<bool>

Whether all messages of this room are read.

notification_count: Cell<u64>

The number of unread notifications of this room.

has_notifications: Cell<bool>

whether this room has unread notifications.

highlight: Cell<HighlightFlags>

The highlight state of the room.

is_encrypted: Cell<bool>

Whether this room is encrypted.

join_rule: JoinRule

The join rule of this room.

guests_allowed: Cell<bool>

Whether guests are allowed.

history_visibility: Cell<HistoryVisibilityValue>

The visibility of the history.

version: PhantomData<String>

The version of this room.

federated: PhantomData<bool>

Whether this room is federated.

typing_list: TypingList

The list of members currently typing in this room.

typing_drop_guard: OnceCell<EventHandlerDropGuard>notifications_setting: Cell<NotificationsRoomSetting>

The notifications settings for this room.

permissions: Permissions

The permissions of our own user in this room

verification: BoundObjectWeakRef<IdentityVerification>

An ongoing identity verification in this room.

is_room_info_initialized: Cell<bool>

Whether the room info is initialized.

Used to silence logs during initialization.

attempted_auto_join: Cell<bool>

Whether we already attempted an auto-join.

Implementations

Source

impl Room

fn register_type()

Registers the type only once.

Source

impl Room

pub fn downgrade(&self) -> <Self as Downgrade>::Weak

Source

impl Room

pub(super) fn init( &self, matrix_room: MatrixRoom, metainfo: Option<RoomMetainfo>, )

Initialize this room.

pub(super) fn matrix_room(&self) -> &MatrixRoom

The room API of the SDK.

fn set_session(&self, session: &Session)

Set the current session

pub(super) fn room_id(&self) -> &RoomId

The ID of this room.

fn room_id_string(&self) -> String

The ID of this room, as a string.

fn update_name(&self)

Update the name of this room.

async fn update_display_name(&self)

Load the display name from the SDK.

fn set_has_avatar(&self, has_avatar: bool)

Set whether this room has an avatar explicitly set.

fn update_avatar(&self)

Update the avatar of the room.

fn update_topic(&self)

Update the topic of this room.

fn set_category(&self, category: RoomCategory)

Set the category of this room.

pub(super) async fn update_category(&self)

Update the category from the SDK.

async fn set_is_direct(&self, is_direct: bool)

Set whether this room is a direct chat.

pub(super) async fn update_is_direct(&self)

Update whether the room is direct or not.

fn update_tombstone(&self)

Update the tombstone for this room.

pub(super) fn update_successor(&self)

Update the successor of this room.

fn predecessor_id_string(&self) -> Option<String>

The ID of the room that was upgraded and that this one replaces, as a string.

fn load_predecessor(&self)

Load the predecessor of this room.

fn successor_id_string(&self) -> Option<String>

The ID of the successor of this room, if this room was upgraded.

fn set_successor(&self, successor: &Room)

Set the successor of this room.

fn watch_members(&self)

Watch changes in the members list.

fn handle_member_event(&self, event: &SyncRoomMemberEvent)

Handle a member event received via sync

fn set_joined_members_count(&self, count: u64)

Set the number of joined members in the room, according to the homeserver.

pub(super) fn own_member(&self) -> &Member

The member corresponding to our own user.

async fn load_own_member(&self)

Load our own member from the store.

async fn update_is_invite(&self)

Update whether this room is a current invite or an invite that was declined or retracted.

async fn was_membership(&self, membership: &MembershipState) -> bool

Check whether the previous membership of our user in this room matches the one that is given.

async fn update_inviter(&self)

Update the member that invited us to this room.

fn set_direct_member(&self, member: Option<Member>)

Set the other member of the room, if this room is a direct chat and there is only one other member.

async fn direct_user_id(&self) -> Option<OwnedUserId>

The ID of the other user, if this is a direct chat and there is only one other user.

async fn update_direct_member(&self)

Update the other member of the room, if this room is a direct chat and there is only one other member.

fn init_live_timeline(&self)

Initialize the live timeline of this room.

fn live_timeline(&self) -> &Timeline

The live timeline of this room.

pub(super) fn set_latest_activity(&self, latest_activity: u64)

Set the timestamp of the room’s latest possibly unread event.

async fn update_is_marked_unread(&self)

Update whether this room is marked as unread.

fn set_is_read(&self, is_read: bool)

Set whether all messages of this room are read.

async fn handle_read_change_trigger(&self)

Handle the trigger emitted when a read change might have occurred.

fn set_highlight(&self, highlight: HighlightFlags)

Set how this room is highlighted.

fn update_highlight(&self)

Update the highlight of the room from the current state.

fn set_notification_count(&self, count: u64)

Set the number of unread notifications of this room.

fn set_has_notifications(&self, has_notifications: bool)

Set whether this room has unread notifications.

async fn update_is_encrypted(&self)

Update whether the room is encrypted from the SDK.

fn update_guests_allowed(&self)

Update whether guests are allowed.

fn update_history_visibility(&self)

Update the visibility of the history.

fn version(&self) -> String

The version of this room.

pub(super) fn rules(&self) -> RoomVersionRules

The rules for the version of this room.

fn federated(&self) -> bool

Whether this room is federated.

fn set_up_typing(&self)

Start listening to typing events.

fn update_typing_list(&self, typing_user_ids: Vec<OwnedUserId>)

Update the typing list with the given user IDs.

fn set_notifications_setting(&self, setting: NotificationsRoomSetting)

Set the notifications setting for this room.

fn set_verification(&self, verification: Option<IdentityVerification>)

Set an ongoing verification in this room.

fn watch_room_info(&self)

Watch the SDK’s room info for changes to the room state.

async fn update_with_room_info(&self, room_info: RoomInfo)

Update this room with the given SDK room info.

pub(super) fn handle_ambiguity_changes<'a>( &self, changes: impl Iterator<Item = &'a AmbiguityChange>, )

Handle changes in the ambiguity of members display names.

fn watch_send_queue(&self)

Watch errors in the send queue to try to handle them.

pub(super) async fn change_category( &self, category: TargetRoomCategory, ) -> MatrixResult<()>

Change the category of this room.

This makes the necessary to propagate the category to the homeserver.

This can be used to trigger actions like join or leave, as well as changing the category in the sidebar.

Note that rooms cannot change category once they are upgraded.